@@ -5,8 +5,8 @@ use std::path::Path;
 
 #[test]
 fn ogr_to_svg() -> Result<(), gdal::errors::GdalError> {
-    let mut dataset = Dataset::open(Path::new("tests/data/places.json"))?;
-    let layer = dataset.layer(0)?;
+    let dataset = Dataset::open(Path::new("tests/data/places.json"))?;
+    let mut layer = dataset.layer(0)?;
     let mut out: Vec<u8> = Vec::new();
     for feature in layer.features() {
         let geom = feature.geometry();
